@@ -155,3 +155,12 @@ class TestRegionEstimator(unittest.TestCase):
         regions = pd.DataFrame(self.regions)
         regions.index = regions.index.rename('postcode')
         estimator = ConcentricRegionsEstimator(self.sites, regions, self.actuals)
+
+  def test_max_processors(self):
+    """
+    Check that creating new RegionEstimator with
+    """
+
+    with self.assertRaises(AssertionError):
+        # Test that loading incorrect max_processors raises assertion
+        estimator = ConcentricRegionsEstimator(self.sites, self.regions, self.actuals, verbose=0, max_processors=0)
